@@ -9,13 +9,13 @@
 //! R. Buckminster Fuller). The base cells, which make up resolution 0, are
 //! Class II.
 
-use super::{CoordIJK, Vec2d, SQRT3_2};
+use super::{CoordIJK, SQRT3_2, Vec2d};
 use crate::{
+    BaseCell, Boundary, CCW, CW, CellIndex, DEFAULT_CELL_INDEX, Direction,
+    ExtendedResolution, Face, LatLng, NUM_HEX_VERTS, NUM_ICOSA_FACES,
+    NUM_PENT_VERTS, Resolution, Vertex,
     face::{self, FaceOrientIJK},
     index::bits,
-    BaseCell, Boundary, CellIndex, Direction, ExtendedResolution, Face, LatLng,
-    Resolution, Vertex, CCW, CW, DEFAULT_CELL_INDEX, NUM_HEX_VERTS,
-    NUM_ICOSA_FACES, NUM_PENT_VERTS,
 };
 
 static ZERO: CoordIJK = CoordIJK::new(0, 0, 0);
@@ -163,7 +163,7 @@ impl FaceIJK {
     ///
     /// * `resolution` - The H3 resolution of the cell.
     /// * `is_pent4` - Whether or not the cell is a pentagon with a leading
-    ///                digit 4.
+    ///   digit 4.
     /// * `in_substrate` - Whether or not the cell is in a substrate grid.
     pub fn adjust_overage_class2<const IS_SUBSTRATE: bool>(
         &mut self,
@@ -469,7 +469,7 @@ impl FaceIJK {
     /// # Arguments
     ///
     /// * `resolution` - The H3 resolution of the cell. This may be adjusted if
-    ///                  necessary for the substrate grid resolution.
+    ///   necessary for the substrate grid resolution.
     /// * `vertices` - output array for the vertices.
     pub fn vertices(
         &mut self,
