@@ -1,13 +1,12 @@
 //! Functions for altering and converting the color of pixelbufs
 
 use num_traits::NumCast;
-use std::f64::consts::PI;
 
-use crate::color::{FromColor, IntoColor, Luma, LumaA, Rgba};
-use crate::image::{GenericImage, GenericImageView};
+use crate::color::{FromColor, IntoColor, Luma, LumaA};
+use crate::metadata::{CicpColorPrimaries, CicpTransferCharacteristics};
 use crate::traits::{Pixel, Primitive};
 use crate::utils::clamp;
-use crate::ImageBuffer;
+use crate::{GenericImage, GenericImageView, ImageBuffer};
 
 type Subpixel<I> = <<I as GenericImageView>::Pixel as Pixel>::Subpixel;
 
@@ -34,6 +33,7 @@ where
 {
     let (width, height) = image.dimensions();
     let mut out = ImageBuffer::new(width, height);
+    out.copy_color_space_from(&image.buffer_with_dimensions(0, 0));
 
     for (x, y, pixel) in image.pixels() {
         let grayscale = pixel.to_luma();
@@ -54,6 +54,7 @@ where
 {
     let (width, height) = image.dimensions();
     let mut out = ImageBuffer::new(width, height);
+    out.copy_color_space_from(&image.buffer_with_dimensions(0, 0));
 
     for (x, y, pixel) in image.pixels() {
         let grayscale = pixel.to_luma_alpha();
@@ -92,8 +93,7 @@ where
     P: Pixel<Subpixel = S> + 'static,
     S: Primitive + 'static,
 {
-    let (width, height) = image.dimensions();
-    let mut out = ImageBuffer::new(width, height);
+    let mut out = image.buffer_like();
 
     let max = S::DEFAULT_MAX_VALUE;
     let max: f32 = NumCast::from(max).unwrap();
@@ -159,8 +159,7 @@ where
     P: Pixel<Subpixel = S> + 'static,
     S: Primitive + 'static,
 {
-    let (width, height) = image.dimensions();
-    let mut out = ImageBuffer::new(width, height);
+    let mut out = image.buffer_like();
 
     let max = S::DEFAULT_MAX_VALUE;
     let max: i32 = NumCast::from(max).unwrap();
@@ -225,13 +224,12 @@ where
     P: Pixel<Subpixel = S> + 'static,
     S: Primitive + 'static,
 {
-    let (width, height) = image.dimensions();
-    let mut out = ImageBuffer::new(width, height);
+    let mut out = image.buffer_like();
 
     let angle: f64 = NumCast::from(value).unwrap();
 
-    let cosv = (angle * PI / 180.0).cos();
-    let sinv = (angle * PI / 180.0).sin();
+    let cosv = angle.to_radians().cos();
+    let sinv = angle.to_radians().sin();
     let matrix: [f64; 9] = [
         // Reds
         0.213 + cosv * 0.787 - sinv * 0.213,
@@ -280,6 +278,7 @@ where
 }
 
 /// Hue rotate the supplied image in place.
+///
 /// `value` is the degrees to rotate each pixel by.
 /// 0 and 360 do nothing, the rest rotates by the given degree value.
 /// just like the css webkit filter hue-rotate(180)
@@ -293,8 +292,8 @@ where
 
     let angle: f64 = NumCast::from(value).unwrap();
 
-    let cosv = (angle * PI / 180.0).cos();
-    let sinv = (angle * PI / 180.0).sin();
+    let cosv = angle.to_radians().cos();
+    let sinv = angle.to_radians().sin();
     let matrix: [f64; 9] = [
         // Reds
         0.213 + cosv * 0.787 - sinv * 0.213,
@@ -355,12 +354,12 @@ pub trait ColorMap {
     /// in the color map.
     fn index_of(&self, color: &Self::Color) -> usize;
     /// Looks up color by index in the color map.  If `idx` is out of range for the color map, or
-    /// ColorMap doesn't implement `lookup` `None` is returned.
+    /// `ColorMap` doesn't implement `lookup` `None` is returned.
     fn lookup(&self, index: usize) -> Option<Self::Color> {
         let _ = index;
         None
     }
-    /// Determine if this implementation of ColorMap overrides the default `lookup`.
+    /// Determine if this implementation of `ColorMap` overrides the default `lookup`.
     fn has_lookup(&self) -> bool {
         false
     }
@@ -422,7 +421,7 @@ impl ColorMap for BiLevel {
         }
     }
 
-    /// Indicate NeuQuant implements `lookup`.
+    /// Indicate `NeuQuant` implements `lookup`.
     fn has_lookup(&self) -> bool {
         true
     }
@@ -435,11 +434,12 @@ impl ColorMap for BiLevel {
     }
 }
 
+#[cfg(feature = "color_quant")]
 impl ColorMap for color_quant::NeuQuant {
-    type Color = Rgba<u8>;
+    type Color = crate::color::Rgba<u8>;
 
     #[inline(always)]
-    fn index_of(&self, color: &Rgba<u8>) -> usize {
+    fn index_of(&self, color: &Self::Color) -> usize {
         self.index_of(color.channels())
     }
 
@@ -454,8 +454,8 @@ impl ColorMap for color_quant::NeuQuant {
     }
 
     #[inline(always)]
-    fn map_color(&self, color: &mut Rgba<u8>) {
-        self.map_pixel(color.channels_mut())
+    fn map_color(&self, color: &mut Self::Color) {
+        self.map_pixel(color.channels_mut());
     }
 }
 
@@ -534,9 +534,12 @@ where
     Map: ColorMap<Color = Pix> + ?Sized,
     Pix: Pixel<Subpixel = u8> + 'static,
 {
+    // Special case, we do *not* want to copy the color space here.
     let mut indices = ImageBuffer::new(image.width(), image.height());
+    indices.set_rgb_primaries(CicpColorPrimaries::Unspecified);
+    indices.set_transfer_function(CicpTransferCharacteristics::Unspecified);
     for (pixel, idx) in image.pixels().zip(indices.pixels_mut()) {
-        *idx = Luma([color_map.index_of(pixel) as u8])
+        *idx = Luma([color_map.index_of(pixel) as u8]);
     }
     indices
 }
@@ -584,7 +587,7 @@ mod test {
         let cmap = BiLevel;
         dither(&mut image, &cmap);
         assert_eq!(&*image, &[0, 0xFF, 0xFF, 0]);
-        assert_eq!(index_colors(&image, &cmap).into_raw(), vec![0, 1, 1, 0])
+        assert_eq!(index_colors(&image, &cmap).into_raw(), vec![0, 1, 1, 0]);
     }
 
     #[test]
