@@ -26,6 +26,83 @@ unsafe fn convert_ptr_mut<'r, T>(r: *mut u8) -> &'r mut T {
 	unsafe { &mut *(r.cast::<T>()) }
 }
 
+trait MatMatcher {
+	fn match_indices(&self, idx: &[i32]) -> Result<()>;
+	fn match_total(&self, idx: i32) -> Result<()>;
+	fn match_max_dims(&self, max_dims: i32) -> Result<()>;
+	fn match_is_continuous(&self) -> Result<()>;
+}
+
+impl<T: MatTraitConst + ?Sized> MatMatcher for T {
+	fn match_indices(&self, idx: &[i32]) -> Result<()> {
+		let mat_size = self.mat_size();
+		let size = &*mat_size;
+		if size.len() != idx.len() {
+			return Err(Error::new(
+				core::StsUnmatchedSizes,
+				format!(
+					"Amount of Mat dimensions: {} doesn't match the amount of requested indices: {}",
+					size.len(),
+					idx.len()
+				),
+			));
+		}
+		if let Some((out_idx, (out_idx_val, out_size))) = idx
+			.iter()
+			.zip(size)
+			.enumerate()
+			.find(|(_, (idx_val, &size))| !(0..size).contains(idx_val))
+		{
+			Err(Error::new(
+				core::StsOutOfRange,
+				format!("Index: {out_idx_val} along dimension: {out_idx} out of bounds 0..{out_size}"),
+			))
+		} else {
+			Ok(())
+		}
+	}
+
+	#[inline]
+	fn match_total(&self, idx: i32) -> Result<()> {
+		let size = self.total();
+		// safe because of the `0 <= idx` check
+		if 0 <= idx && (idx as usize) < size {
+			Ok(())
+		} else {
+			Err(Error::new(
+				core::StsOutOfRange,
+				format!("Index: {idx} out of bounds: 0..{size}"),
+			))
+		}
+	}
+
+	#[inline]
+	fn match_max_dims(&self, max_dims: i32) -> Result<()> {
+		let dims = self.dims();
+		// safe because of the `0 <= idx` check
+		if (0..=max_dims).contains(&dims) {
+			Ok(())
+		} else {
+			Err(Error::new(
+				core::StsOutOfRange,
+				format!("Mat contains too many dimensions: {dims}, maximum for this operation: {max_dims}"),
+			))
+		}
+	}
+
+	#[inline]
+	fn match_is_continuous(&self) -> Result<()> {
+		if self.is_continuous() {
+			Ok(())
+		} else {
+			Err(Error::new(
+				core::StsUnmatchedSizes,
+				"Mat is not continuous, operation is not applicable",
+			))
+		}
+	}
+}
+
 #[inline]
 fn match_format<T: DataType>(mat_type: i32) -> Result<()> {
 	let out_type = T::opencv_type();
@@ -41,60 +118,6 @@ fn match_format<T: DataType>(mat_type: i32) -> Result<()> {
 	}
 }
 
-fn match_indices(mat: &(impl MatTraitConst + ?Sized), idx: &[i32]) -> Result<()> {
-	let mat_size = mat.mat_size();
-	let size = &*mat_size;
-	if size.len() != idx.len() {
-		return Err(Error::new(
-			core::StsUnmatchedSizes,
-			format!(
-				"Amount of Mat dimensions: {} doesn't match the amount of requested indices: {}",
-				size.len(),
-				idx.len()
-			),
-		));
-	}
-	if let Some((out_idx, (out_idx_val, out_size))) = idx
-		.iter()
-		.zip(size)
-		.enumerate()
-		.find(|(_, (idx_val, &size))| !(0..size).contains(idx_val))
-	{
-		Err(Error::new(
-			core::StsOutOfRange,
-			format!("Index: {out_idx_val} along dimension: {out_idx} out of bounds 0..{out_size}"),
-		))
-	} else {
-		Ok(())
-	}
-}
-
-#[inline]
-fn match_total(mat: &(impl MatTraitConst + ?Sized), idx: i32) -> Result<()> {
-	let size = mat.total();
-	// safe because of the `0 <= idx` check
-	if 0 <= idx && (idx as usize) < size {
-		Ok(())
-	} else {
-		Err(Error::new(
-			core::StsOutOfRange,
-			format!("Index: {idx} out of bounds: 0..{size}"),
-		))
-	}
-}
-
-#[inline]
-fn match_is_continuous(mat: &(impl MatTraitConst + ?Sized)) -> Result<()> {
-	if mat.is_continuous() {
-		Ok(())
-	} else {
-		Err(Error::new(
-			core::StsUnmatchedSizes,
-			"Mat is not continuous, operation is not applicable",
-		))
-	}
-}
-
 fn match_length(sizes: &[i32], slice_len: usize, size_mul: usize) -> Result<()> {
 	let mut expected_len: u64 = 1;
 	for (i, size) in sizes.iter().enumerate() {
@@ -151,34 +174,34 @@ fn col_count_i32(col_count: usize) -> Result<i32> {
 }
 
 impl Mat {
-	/// Create new `Mat` from the iterator of known size
+	/// Create a new [Mat] from the iterator of known size
 	pub fn from_exact_iter<T: DataType>(s: impl ExactSizeIterator<Item = T>) -> Result<Self> {
-		let mut out = unsafe { Self::new_rows_cols(row_count_i32(s.len())?, 1, T::opencv_type()) }?;
+		let mut out = unsafe { Self::new_rows_cols(1, col_count_i32(s.len())?, T::opencv_type()) }?;
 		for (i, x) in s.enumerate() {
 			// safe because `row_count_i32` ensures that len of `s` fits `i32`
 			let i = i as i32;
-			unsafe { ptr::write(out.at_unchecked_mut::<T>(i)?, x) };
+			unsafe { ptr::write(out.at_unchecked_mut::<T>(i), x) };
 		}
 		Ok(out)
 	}
 
-	/// Create a new `Mat` from a single-dimensional slice
+	/// Create a new [Mat] from a single-dimensional slice
 	#[inline]
-	pub fn from_slice<T: DataType>(s: &[T]) -> Result<BoxedRef<Self>> {
+	pub fn from_slice<T: DataType>(s: &[T]) -> Result<BoxedRef<'_, Self>> {
 		Self::new_rows_cols_with_data(1, i32::try_from(s.len())?, s)
 	}
 
-	/// Create a new `Mat` from a single-dimensional byte slice
+	/// Create a new [Mat] from a single-dimensional byte slice
 	#[inline]
-	pub fn from_bytes<T: DataType>(s: &[u8]) -> Result<BoxedRef<Self>> {
+	pub fn from_bytes<T: DataType>(s: &[u8]) -> Result<BoxedRef<'_, Self>> {
 		let rem = s.len() % mem::size_of::<T>();
 		if rem != 0 {
 			return Err(Error::new(
 				core::StsBadArg,
 				format!(
-					"Unexpected number of bytes: {} the indicated type, expected multiple of {}",
+					"Unexpected number of bytes: {}, expected multiple of: {} based on the indicated type",
 					s.len(),
-					T::opencv_channels()
+					mem::size_of::<T>()
 				),
 			));
 		}
@@ -186,17 +209,17 @@ impl Mat {
 		Self::new_rows_cols_with_bytes::<T>(1, i32::try_from(len)?, s)
 	}
 
-	/// Create a new `Mat` from a mutable single-dimensional byte slice
+	/// Create a new [Mat] from a mutable single-dimensional byte slice
 	#[inline]
-	pub fn from_bytes_mut<T: DataType>(s: &mut [u8]) -> Result<BoxedRefMut<Self>> {
+	pub fn from_bytes_mut<T: DataType>(s: &mut [u8]) -> Result<BoxedRefMut<'_, Self>> {
 		let rem = s.len() % mem::size_of::<T>();
 		if rem != 0 {
 			return Err(Error::new(
 				core::StsBadArg,
 				format!(
-					"Unexpected number of bytes: {} the indicated type, expected multiple of {}",
+					"Unexpected number of bytes: {}, expected multiple of: {} based on the indicated type",
 					s.len(),
-					T::opencv_channels()
+					mem::size_of::<T>()
 				),
 			));
 		}
@@ -204,13 +227,13 @@ impl Mat {
 		Self::new_rows_cols_with_bytes_mut::<T>(1, i32::try_from(len)?, s)
 	}
 
-	/// Create a new `Mat` from a mutable single-dimensional slice
+	/// Create a new [Mat] from a mutable single-dimensional slice
 	#[inline]
-	pub fn from_slice_mut<T: DataType>(s: &mut [T]) -> Result<BoxedRefMut<Self>> {
+	pub fn from_slice_mut<T: DataType>(s: &mut [T]) -> Result<BoxedRefMut<'_, Self>> {
 		Self::new_rows_cols_with_data_mut(1, i32::try_from(s.len())?, s)
 	}
 
-	/// Create a new `Mat` by copying the data from a slice of slices
+	/// Create a new 2D [Mat] by copying the data from a slice of slices
 	///
 	/// Every subslice must have the same length, otherwise an error is returned.
 	pub fn from_slice_2d<T: DataType>(s: &[impl AsRef<[T]>]) -> Result<Self> {
@@ -247,9 +270,9 @@ impl Mat {
 		Ok(out)
 	}
 
-	/// Create a new `Mat` that references a single-dimensional slice with custom shape
+	/// Create a new [Mat] that references a single-dimensional slice with a custom shape
 	#[inline]
-	pub fn new_rows_cols_with_data<T: DataType>(rows: i32, cols: i32, data: &[T]) -> Result<BoxedRef<Self>> {
+	pub fn new_rows_cols_with_data<T: DataType>(rows: i32, cols: i32, data: &[T]) -> Result<BoxedRef<'_, Self>> {
 		match_length(&[rows, cols], data.len(), 1)?;
 		let m = unsafe {
 			Self::new_rows_cols_with_data_unsafe_def(rows, cols, T::opencv_type(), data.as_ptr().cast::<c_void>().cast_mut())
@@ -257,9 +280,9 @@ impl Mat {
 		Ok(<BoxedRef<Mat>>::from(m))
 	}
 
-	/// Create a new `Mat` that references a single-dimensional byte slice with custom shape
+	/// Create a new [Mat] that references a single-dimensional byte slice with a custom shape
 	#[inline]
-	pub fn new_rows_cols_with_bytes<T: DataType>(rows: i32, cols: i32, data: &[u8]) -> Result<BoxedRef<Self>> {
+	pub fn new_rows_cols_with_bytes<T: DataType>(rows: i32, cols: i32, data: &[u8]) -> Result<BoxedRef<'_, Self>> {
 		match_length(&[rows, cols], data.len(), mem::size_of::<T>())?;
 		let m = unsafe {
 			Self::new_rows_cols_with_data_unsafe_def(rows, cols, T::opencv_type(), data.as_ptr().cast::<c_void>().cast_mut())
@@ -267,41 +290,41 @@ impl Mat {
 		Ok(<BoxedRef<Mat>>::from(m))
 	}
 
-	/// Create a new mutable `Mat` that references a single-dimensional slice with custom shape
+	/// Create a new mutable [Mat] that references a single-dimensional slice with a custom shape
 	#[inline]
-	pub fn new_rows_cols_with_data_mut<T: DataType>(rows: i32, cols: i32, data: &mut [T]) -> Result<BoxedRefMut<Self>> {
+	pub fn new_rows_cols_with_data_mut<T: DataType>(rows: i32, cols: i32, data: &mut [T]) -> Result<BoxedRefMut<'_, Self>> {
 		match_length(&[rows, cols], data.len(), 1)?;
 		let m =
 			unsafe { Self::new_rows_cols_with_data_unsafe_def(rows, cols, T::opencv_type(), data.as_mut_ptr().cast::<c_void>()) }?;
 		Ok(<BoxedRefMut<Mat>>::from(m))
 	}
 
-	/// Create a new mutable `Mat` that references a single-dimensional byte slice with custom shape
+	/// Create a new mutable [Mat] that references a single-dimensional byte slice with a custom shape
 	#[inline]
-	pub fn new_rows_cols_with_bytes_mut<T: DataType>(rows: i32, cols: i32, data: &mut [u8]) -> Result<BoxedRefMut<Self>> {
+	pub fn new_rows_cols_with_bytes_mut<T: DataType>(rows: i32, cols: i32, data: &mut [u8]) -> Result<BoxedRefMut<'_, Self>> {
 		match_length(&[rows, cols], data.len(), mem::size_of::<T>())?;
 		let m =
 			unsafe { Self::new_rows_cols_with_data_unsafe_def(rows, cols, T::opencv_type(), data.as_mut_ptr().cast::<c_void>()) }?;
 		Ok(<BoxedRefMut<Mat>>::from(m))
 	}
 
-	/// Create a new `Mat` that references a single-dimensional slice with custom shape
+	/// Create a new [Mat] that references a single-dimensional slice with a custom shape
 	#[inline]
-	pub fn new_size_with_data<T: DataType>(size: Size, data: &[T]) -> Result<BoxedRef<Self>> {
+	pub fn new_size_with_data<T: DataType>(size: Size, data: &[T]) -> Result<BoxedRef<'_, Self>> {
 		match_length(&[size.width, size.height], data.len(), 1)?;
 		let m = unsafe { Self::new_size_with_data_unsafe_def(size, T::opencv_type(), data.as_ptr().cast::<c_void>().cast_mut()) }?;
 		Ok(<BoxedRef<Mat>>::from(m))
 	}
 
-	/// Create a new mutable `Mat` that references a single-dimensional slice with custom shape
+	/// Create a new mutable [Mat] that references a single-dimensional slice with a custom shape
 	#[inline]
-	pub fn new_size_with_data_mut<T: DataType>(size: Size, data: &mut [T]) -> Result<BoxedRefMut<Self>> {
+	pub fn new_size_with_data_mut<T: DataType>(size: Size, data: &mut [T]) -> Result<BoxedRefMut<'_, Self>> {
 		match_length(&[size.width, size.height], data.len(), 1)?;
 		let m = unsafe { Self::new_size_with_data_unsafe_def(size, T::opencv_type(), data.as_mut_ptr().cast::<c_void>()) }?;
 		Ok(<BoxedRefMut<Mat>>::from(m))
 	}
 
-	/// Create a new `Mat` that references a single-dimensional slice with custom shape
+	/// Create a new [Mat] that references a single-dimensional slice with a custom shape
 	#[inline]
 	pub fn new_nd_with_data<'data, T: DataType>(sizes: &[i32], data: &'data [T]) -> Result<BoxedRef<'data, Self>> {
 		match_length(sizes, data.len(), 1)?;
@@ -309,7 +332,7 @@ impl Mat {
 		Ok(<BoxedRef<Mat>>::from(m))
 	}
 
-	/// Create a new `Mat` that references a single-dimensional slice with custom shape
+	/// Create a new [Mat] that references a single-dimensional slice with a custom shape
 	#[inline]
 	pub fn new_nd_with_data_mut<'data, T: DataType>(sizes: &[i32], data: &'data mut [T]) -> Result<BoxedRefMut<'data, Self>> {
 		match_length(sizes, data.len(), 1)?;
@@ -317,8 +340,8 @@ impl Mat {
 		Ok(<BoxedRefMut<Mat>>::from(m))
 	}
 
-	/// Returns 2 mutable ROIs into a single `Mat` as long as they do not intersect
-	pub fn roi_2_mut<MAT: MatTrait>(m: &mut MAT, roi1: Rect, roi2: Rect) -> Result<(BoxedRefMut<Mat>, BoxedRefMut<Mat>)> {
+	/// Returns 2 mutable ROIs into a single [Mat] as long as they do not intersect
+	pub fn roi_2_mut<MAT: MatTrait>(m: &mut MAT, roi1: Rect, roi2: Rect) -> Result<(BoxedRefMut<'_, Mat>, BoxedRefMut<'_, Mat>)> {
 		if (roi1 & roi2).empty() {
 			// safe because we made sure that the interest areas do not intersect
 			let m2 = unsafe { (m as *mut MAT).as_mut().expect("Can't fail") };
@@ -403,8 +426,9 @@ pub(crate) mod mat_forward {
 	#[inline]
 	pub fn at<T: DataType>(mat: &(impl MatTraitConst + ?Sized), i0: i32) -> Result<&T> {
 		match_format::<T>(mat.typ())
-			.and_then(|_| match_total(mat, i0))
-			.and_then(|_| unsafe { mat.at_unchecked(i0) })
+			.and_then(|_| mat.match_total(i0))
+			.and_then(|_| mat.match_max_dims(2))
+			.map(|_| unsafe { mat.at_unchecked(i0) })
 	}
 
 	#[inline]
@@ -414,8 +438,8 @@ pub(crate) mod mat_forward {
 
 	#[inline]
 	pub fn at_mut<T: DataType>(mat: &mut (impl MatTrait + ?Sized), i0: i32) -> Result<&mut T> {
-		match_format::<T>(mat.typ()).and_then(|_| match_total(mat, i0))?;
-		unsafe { mat.at_unchecked_mut(i0) }
+		match_format::<T>(mat.typ()).and_then(|_| mat.match_total(i0))?;
+		Ok(unsafe { mat.at_unchecked_mut(i0) })
 	}
 
 	#[inline]
@@ -426,13 +450,13 @@ pub(crate) mod mat_forward {
 	#[inline]
 	pub fn at_2d<T: DataType>(mat: &(impl MatTraitConst + ?Sized), row: i32, col: i32) -> Result<&T> {
 		match_format::<T>(mat.typ())
-			.and_then(|_| match_indices(mat, &[row, col]))
+			.and_then(|_| mat.match_indices(&[row, col]))
 			.and_then(|_| unsafe { mat.at_2d_unchecked(row, col) })
 	}
 
 	#[inline]
 	pub fn at_2d_mut<T: DataType>(mat: &mut (impl MatTrait + ?Sized), row: i32, col: i32) -> Result<&mut T> {
-		match_format::<T>(mat.typ()).and_then(|_| match_indices(mat, &[row, col]))?;
+		match_format::<T>(mat.typ()).and_then(|_| mat.match_indices(&[row, col]))?;
 		unsafe { mat.at_2d_unchecked_mut(row, col) }
 	}
 
@@ -449,41 +473,41 @@ pub(crate) mod mat_forward {
 	#[inline]
 	pub fn at_3d<T: DataType>(mat: &(impl MatTraitConst + ?Sized), i0: i32, i1: i32, i2: i32) -> Result<&T> {
 		match_format::<T>(mat.typ())
-			.and_then(|_| match_indices(mat, &[i0, i1, i2]))
+			.and_then(|_| mat.match_indices(&[i0, i1, i2]))
 			.and_then(|_| unsafe { mat.at_3d_unchecked(i0, i1, i2) })
 	}
 
 	#[inline]
 	pub fn at_3d_mut<T: DataType>(mat: &mut (impl MatTrait + ?Sized), i0: i32, i1: i32, i2: i32) -> Result<&mut T> {
-		match_format::<T>(mat.typ()).and_then(|_| match_indices(mat, &[i0, i1, i2]))?;
+		match_format::<T>(mat.typ()).and_then(|_| mat.match_indices(&[i0, i1, i2]))?;
 		unsafe { mat.at_3d_unchecked_mut(i0, i1, i2) }
 	}
 
 	#[inline]
 	pub fn at_nd<'s, T: DataType>(mat: &'s (impl MatTraitConst + ?Sized), idx: &[i32]) -> Result<&'s T> {
 		match_format::<T>(mat.typ())
-			.and_then(|_| match_indices(mat, idx))
+			.and_then(|_| mat.match_indices(idx))
 			.and_then(|_| unsafe { mat.at_nd_unchecked(idx) })
 	}
 
 	#[inline]
 	pub fn at_nd_mut<'s, T: DataType>(mat: &'s mut (impl MatTrait + ?Sized), idx: &[i32]) -> Result<&'s mut T> {
-		match_format::<T>(mat.typ()).and_then(|_| match_indices(mat, idx))?;
+		match_format::<T>(mat.typ()).and_then(|_| mat.match_indices(idx))?;
 		unsafe { mat.at_nd_unchecked_mut(idx) }
 	}
 }
 
 pub trait MatTraitConstManual: MatTraitConst {
-	/// Like `Mat::at()` but performs no bounds or type checks
+	/// Like [Mat::at()] but performs no bounds or type checks
 	///
 	/// # Safety
 	/// Caller must ensure that index is within Mat bounds
 	#[inline]
-	unsafe fn at_unchecked<T: DataType>(&self, i0: i32) -> Result<&T> {
-		Ok(unsafe { &*data_at_idx::<T>(self, i0 as usize) })
+	unsafe fn at_unchecked<T: DataType>(&self, i0: i32) -> &T {
+		unsafe { &*data_at_idx::<T>(self, i0 as usize) }
 	}
 
-	/// Like `Mat::at_2d()` but performs no bounds or type checks
+	/// Like [Mat::at_2d()] but performs no bounds or type checks
 	/// # Safety
 	/// Caller must ensure that indices are within Mat bounds
 	#[inline]
@@ -491,7 +515,7 @@ pub trait MatTraitConstManual: MatTraitConst {
 		self.ptr_2d(row, col).map(|ptr| unsafe { convert_ptr(ptr) })
 	}
 
-	/// Like `Mat::at_pt()` but performs no bounds or type checks
+	/// Like [Mat::at_pt()] but performs no bounds or type checks
 	/// # Safety
 	/// Caller must ensure that point is within Mat bounds
 	#[inline]
@@ -499,7 +523,7 @@ pub trait MatTraitConstManual: MatTraitConst {
 		unsafe { self.at_2d_unchecked(pt.y, pt.x) }
 	}
 
-	/// Like `Mat::at_3d()` but performs no bounds or type checks
+	/// Like [Mat::at_3d()] but performs no bounds or type checks
 	/// # Safety
 	/// Caller must ensure that indices are within Mat bounds
 	#[inline]
@@ -507,7 +531,7 @@ pub trait MatTraitConstManual: MatTraitConst {
 		self.ptr_3d(i0, i1, i2).map(|ptr| unsafe { convert_ptr(ptr) })
 	}
 
-	/// Like `Mat::at_nd()` but performs no bounds or type checks
+	/// Like [Mat::at_nd()] but performs no bounds or type checks
 	/// # Safety
 	/// Caller must ensure that indices are within Mat bounds
 	#[inline]
@@ -519,11 +543,11 @@ pub trait MatTraitConstManual: MatTraitConst {
 	#[inline]
 	fn at_row<T: DataType>(&self, row: i32) -> Result<&[T]> {
 		match_format::<T>(self.typ())
-			.and_then(|_| match_indices(self, &[row, 0]))
+			.and_then(|_| self.match_indices(&[row, 0]))
 			.and_then(|_| unsafe { self.at_row_unchecked(row) })
 	}
 
-	/// Like `Mat::at_row()` but performs no bounds or type checks
+	/// Like [Mat::at_row()] but performs no bounds or type checks
 	/// # Safety
 	/// Caller must ensure that index is within Mat bounds
 	#[inline]
@@ -544,10 +568,10 @@ pub trait MatTraitConstManual: MatTraitConst {
 		!self.data().is_null()
 	}
 
-	/// Returns underlying data array as byte slice, `Mat` must be continuous
+	/// Returns the underlying data array as a byte slice, [Mat] must be continuous
 	#[inline]
 	fn data_bytes(&self) -> Result<&[u8]> {
-		match_is_continuous(self).and_then(|_| {
+		self.match_is_continuous().and_then(|_| {
 			let data = self.data();
 			Ok(if data.is_null() {
 				&[]
@@ -560,12 +584,12 @@ pub trait MatTraitConstManual: MatTraitConst {
 	#[inline]
 	fn data_typed<T: DataType>(&self) -> Result<&[T]> {
 		match_format::<T>(self.typ())
-			.and_then(|_| match_is_continuous(self))
+			.and_then(|_| self.match_is_continuous())
 			.and_then(|_| unsafe { self.data_typed_unchecked() })
 	}
 
 	/// # Safety
-	/// Caller must ensure that the `T` type argument corresponds to the data stored in the `Mat` and `Mat` is continuous
+	/// Caller must ensure that the `T` type argument corresponds to the data stored in the [Mat], and [Mat] is continuous
 	#[inline]
 	unsafe fn data_typed_unchecked<T: DataType>(&self) -> Result<&[T]> {
 		let data = self.data();
@@ -617,9 +641,9 @@ pub trait MatTraitConstManual: MatTraitConst {
 		})
 	}
 
-	/// Returns an iterator over `Mat` elements and their positions
+	/// Returns an iterator over [Mat] elements and their positions
 	#[inline]
-	fn iter<T: DataType>(&self) -> Result<MatIter<T>>
+	fn iter<T: DataType>(&self) -> Result<MatIter<'_, T>>
 	where
 		Self: Sized,
 	{
@@ -643,15 +667,15 @@ pub trait MatTraitConstManual: MatTraitConst {
 }
 
 pub trait MatTraitManual: MatTraitConstManual + MatTrait {
-	/// Like `Mat::at_mut()` but performs no bounds or type checks
+	/// Like [Mat::at_mut()] but performs no bounds or type checks
 	/// # Safety
 	/// Caller must ensure that index is within Mat bounds
 	#[inline]
-	unsafe fn at_unchecked_mut<T: DataType>(&mut self, i0: i32) -> Result<&mut T> {
-		Ok(unsafe { &mut *data_at_idx::<T>(self, i0 as usize).cast_mut() })
+	unsafe fn at_unchecked_mut<T: DataType>(&mut self, i0: i32) -> &mut T {
+		unsafe { &mut *data_at_idx::<T>(self, i0 as usize).cast_mut() }
 	}
 
-	/// Like `Mat::at_2d_mut()` but performs no bounds or type checks
+	/// Like [Mat::at_2d_mut()] but performs no bounds or type checks
 	/// # Safety
 	/// Caller must ensure that indices are within Mat bounds
 	#[inline]
@@ -659,7 +683,7 @@ pub trait MatTraitManual: MatTraitConstManual + MatTrait {
 		self.ptr_2d_mut(row, col).map(|ptr| unsafe { convert_ptr_mut(ptr) })
 	}
 
-	/// Like `Mat::at_pt_mut()` but performs no bounds or type checks
+	/// Like [Mat::at_pt_mut()] but performs no bounds or type checks
 	/// # Safety
 	/// Caller must ensure that point is within Mat bounds
 	#[inline]
@@ -667,7 +691,7 @@ pub trait MatTraitManual: MatTraitConstManual + MatTrait {
 		unsafe { self.at_2d_unchecked_mut(pt.y, pt.x) }
 	}
 
-	/// Like `Mat::at_3d_mut()` but performs no bounds or type checks
+	/// Like [Mat::at_3d_mut()] but performs no bounds or type checks
 	/// # Safety
 	/// Caller must ensure that indices are within Mat bounds
 	#[inline]
@@ -675,7 +699,7 @@ pub trait MatTraitManual: MatTraitConstManual + MatTrait {
 		self.ptr_3d_mut(i0, i1, i2).map(|ptr| unsafe { convert_ptr_mut(ptr) })
 	}
 
-	/// Like `Mat::at_nd_mut()` but performs no bounds or type checks
+	/// Like [Mat::at_nd_mut()] but performs no bounds or type checks
 	/// # Safety
 	/// Caller must ensure that indices are within Mat bounds
 	#[inline]
@@ -686,11 +710,11 @@ pub trait MatTraitManual: MatTraitConstManual + MatTrait {
 	/// Return a complete writeable row
 	#[inline]
 	fn at_row_mut<T: DataType>(&mut self, row: i32) -> Result<&mut [T]> {
-		match_format::<T>(self.typ()).and_then(|_| match_indices(self, &[row, 0]))?;
+		match_format::<T>(self.typ()).and_then(|_| self.match_indices(&[row, 0]))?;
 		unsafe { self.at_row_unchecked_mut(row) }
 	}
 
-	/// Like `Mat::at_row_mut()` but performs no bounds or type checks
+	/// Like [Mat::at_row_mut()] but performs no bounds or type checks
 	/// # Safety
 	/// Caller must ensure that index is within Mat bounds
 	#[inline]
@@ -706,10 +730,10 @@ pub trait MatTraitManual: MatTraitConstManual + MatTrait {
 		})
 	}
 
-	/// Returns underlying data array as mutable byte slice, Mat must be continuous.
+	/// Returns the underlying data array as a mutable byte slice, Mat must be continuous.
 	#[inline]
 	fn data_bytes_mut(&mut self) -> Result<&mut [u8]> {
-		match_is_continuous(self).and_then(|_| {
+		self.match_is_continuous().and_then(|_| {
 			let data = self.data_mut();
 			Ok(if data.is_null() {
 				&mut []
@@ -721,12 +745,12 @@ pub trait MatTraitManual: MatTraitConstManual + MatTrait {
 
 	#[inline]
 	fn data_typed_mut<T: DataType>(&mut self) -> Result<&mut [T]> {
-		match_format::<T>(self.typ()).and_then(|_| match_is_continuous(self))?;
+		match_format::<T>(self.typ()).and_then(|_| self.match_is_continuous())?;
 		unsafe { self.data_typed_unchecked_mut() }
 	}
 
 	/// # Safety
-	/// Caller must ensure that the `T` type argument corresponds to the data stored in the `Mat` and `Mat` is continuous
+	/// Caller must ensure that the `T` type argument corresponds to the data stored in the [Mat], and [Mat] is continuous
 	#[inline]
 	unsafe fn data_typed_unchecked_mut<T: DataType>(&mut self) -> Result<&mut [T]> {
 		let total = self.total();
@@ -738,9 +762,9 @@ pub trait MatTraitManual: MatTraitConstManual + MatTrait {
 		})
 	}
 
-	/// Returns a mutable iterator over `Mat` elements and their positions
+	/// Returns a mutable iterator over [Mat] elements and their positions
 	#[inline]
-	fn iter_mut<T: DataType>(&mut self) -> Result<MatIterMut<T>>
+	fn iter_mut<T: DataType>(&mut self) -> Result<MatIterMut<'_, T>>
 	where
 		Self: Sized,
 	{
@@ -790,11 +814,12 @@ impl fmt::Debug for Mat {
 			.field("channels", &self.channels())
 			.field("depth", &depth)
 			.field("dims", &self.dims())
-			.field("size", &self.size().map_err(|_| fmt::Error)?)
 			.field("rows", &self.rows())
 			.field("cols", &self.cols())
+			.field("mat_size", &self.mat_size())
 			.field("elem_size", &self.elem_size().map_err(|_| fmt::Error)?)
 			.field("elem_size1", &self.elem_size1())
+			.field("mat_step", &self.mat_step())
 			.field("total", &self.total())
 			.field("is_continuous", &self.is_continuous())
 			.field("is_submatrix", &self.is_submatrix())
