@@ -8,7 +8,6 @@ use std::{fmt, iter};
 use clang::{Accessibility, Entity, EntityKind};
 pub use desc::ClassDesc;
 
-use crate::comment::strip_doxygen_comment_markers;
 use crate::debug::{DefinitionLocation, LocationName};
 use crate::element::ExcludeKind;
 use crate::entity::{ControlFlowExt, ToEntity};
@@ -160,14 +159,18 @@ impl<'tu, 'ge> Class<'tu, 'ge> {
 	}
 
 	/// Special case of an empty class with only an anonymous enum inside (e.g., DrawLinesMatchesFlags)
-	pub fn as_enum(&self) -> Option<Enum<'tu>> {
+	pub fn as_enum(&self) -> Option<Enum<'tu, 'ge>> {
 		match self {
-			&Self::Clang { entity, .. } => {
+			&Self::Clang { entity, gen_env, .. } => {
 				if !self.has_methods() && !self.has_fields() && !self.has_descendants() && !self.has_bases() {
 					let children = entity.get_children();
 					if let [single] = children.as_slice() {
 						if matches!(single.get_kind(), EntityKind::EnumDecl) {
-							Some(Enum::new_ext(*single, self.cpp_name(CppNameStyle::Declaration).as_ref()))
+							Some(Enum::new_ext(
+								*single,
+								self.cpp_name(CppNameStyle::Declaration).as_ref(),
+								gen_env,
+							))
 						} else {
 							None
 						}
@@ -236,7 +239,7 @@ impl<'tu, 'ge> Class<'tu, 'ge> {
 		}
 	}
 
-	pub fn bases(&self) -> Cow<[Class<'tu, 'ge>]> {
+	pub fn bases(&self) -> Cow<'_, [Class<'tu, 'ge>]> {
 		match self {
 			&Self::Clang { entity, gen_env, .. } => {
 				let mut out = vec![];
@@ -640,16 +643,16 @@ impl Element for Class<'_, '_> {
 		}
 	}
 
-	fn doc_comment(&self) -> Cow<str> {
+	fn doc_comment(&self) -> Cow<'_, str> {
 		match self {
-			&Self::Clang { entity, .. } => strip_doxygen_comment_markers(&entity.get_comment().unwrap_or_default()).into(),
+			Self::Clang { entity, .. } => entity.doc_comment(),
 			Self::Desc(_) => "".into(),
 		}
 	}
 
-	fn cpp_namespace(&self) -> Cow<str> {
+	fn cpp_namespace(&self) -> Cow<'_, str> {
 		#[inline(always)]
-		fn inner(cpp_fullname: &str) -> Cow<str> {
+		fn inner(cpp_fullname: &str) -> Cow<'_, str> {
 			cpp_fullname.namespace().into()
 		}
 
@@ -663,7 +666,7 @@ impl Element for Class<'_, '_> {
 		}
 	}
 
-	fn cpp_name(&self, style: CppNameStyle) -> Cow<str> {
+	fn cpp_name(&self, style: CppNameStyle) -> Cow<'_, str> {
 		match self {
 			Self::Clang {
 				custom_fullname: Some(cpp_fullname),
