@@ -40,6 +40,7 @@ macro_rules! pred {
 }
 
 use std::collections::{BTreeSet, HashMap, HashSet};
+use std::sync::LazyLock;
 
 pub use argument_names::{ARGUMENT_NAMES_MULTIPLE_SLICE, ARGUMENT_NAMES_NOT_SLICE, ARGUMENT_NAMES_USERDATA};
 pub use argument_override::{
@@ -50,6 +51,7 @@ pub use class_tweaks::{class_tweaks_factory, ClassTweak, ClassTweaks};
 pub use const_tweak::CONST_TYPE_OVERRIDE;
 pub use element_exclude_kind::ELEMENT_EXCLUDE_KIND;
 pub use element_export_tweak::ELEMENT_EXPORT_TWEAK;
+pub use enum_bitfield_override::{enum_bitfield_override_factory, EnumBitfieldOverride};
 pub use force_infallible::{force_infallible_factory, ForceInfallible};
 pub use func_cfg_attr::{func_cfg_attr_factory, FuncCfgAttr, CFG_ATTR_NOT_ON_WINDOWS, CFG_ATTR_ONLY_OPENCV_5};
 pub use func_companion_tweak::{func_companion_tweak_factory, CompanionTweak, FuncCompanionTweak};
@@ -64,7 +66,6 @@ pub use implemented::{
 	IMPLEMENTED_CONST_GENERICS, IMPLEMENTED_FUNCTION_LIKE_MACROS, IMPLEMENTED_GENERICS, IMPLEMENTED_MANUAL_DEBUG,
 	IMPLEMENTED_SYSTEM_CLASSES,
 };
-use once_cell::sync::Lazy;
 pub use property_tweaks::{property_tweaks_factory, PropertyReadWrite, PropertyTweak, PropertyTweaks};
 
 use crate::func::{FuncMatcher, UsageTracker};
@@ -77,6 +78,7 @@ mod class_tweaks;
 mod const_tweak;
 mod element_exclude_kind;
 mod element_export_tweak;
+mod enum_bitfield_override;
 mod force_infallible;
 mod func_cfg_attr;
 mod func_companion_tweak;
@@ -97,6 +99,7 @@ pub type TypeRefFactory = fn() -> TypeRef<'static, 'static>;
 pub struct Settings {
 	pub arg_override: ArgOverride,
 	pub return_override: ReturnOverride,
+	pub enum_bitfield_override: EnumBitfieldOverride,
 	pub force_infallible: ForceInfallible,
 	pub func_cfg_attr: FuncCfgAttr,
 	pub func_companion_tweak: FuncCompanionTweak,
@@ -117,6 +120,7 @@ impl Settings {
 		Self {
 			arg_override: ArgOverride::empty(),
 			return_override: ReturnOverride::empty(),
+			enum_bitfield_override: EnumBitfieldOverride::default(),
 			force_infallible: ForceInfallible::empty(),
 			func_cfg_attr: FuncCfgAttr::empty(),
 			func_companion_tweak: FuncCompanionTweak::empty(),
@@ -137,6 +141,7 @@ impl Settings {
 		Self {
 			arg_override: arg_override_factory(module),
 			return_override: return_override_factory(module),
+			enum_bitfield_override: enum_bitfield_override_factory(module),
 			force_infallible: force_infallible_factory(module),
 			func_cfg_attr: func_cfg_attr_factory(module),
 			func_companion_tweak: func_companion_tweak_factory(module),
@@ -163,7 +168,7 @@ impl Settings {
 		self.func_unsafe.start_usage_tracking();
 	}
 
-	pub fn finish_usage_tracking(&mut self) -> HashMap<&'static str, HashSet<UsageTracker>> {
+	pub fn finish_usage_tracking(&mut self) -> HashMap<&'static str, HashSet<UsageTracker<'_>>> {
 		HashMap::from([
 			("ARG_OVERRIDE", self.arg_override.finish_usage_tracking()),
 			("RETURN_OVERRIDE", self.return_override.finish_usage_tracking()),
@@ -179,7 +184,7 @@ impl Settings {
 /// map of reserved Rust keywords and their replacement to be used in var, function and class names
 /// key: reserved keyword
 /// value: replacement
-pub static RESERVED_RENAME: Lazy<HashMap<&str, &str>> = Lazy::new(|| {
+pub static RESERVED_RENAME: LazyLock<HashMap<&str, &str>> = LazyLock::new(|| {
 	HashMap::from([
 		("box", "box_"),
 		("fn", "fn_"),
@@ -197,7 +202,7 @@ pub static RESERVED_RENAME: Lazy<HashMap<&str, &str>> = Lazy::new(|| {
 });
 
 /// cpp_name(Reference) => ( rust_name(Reference(No)), cpp_name(Reference) )
-pub static PRIMITIVE_TYPEDEFS: Lazy<HashMap<&str, (&str, &str)>> = Lazy::new(|| {
+pub static PRIMITIVE_TYPEDEFS: LazyLock<HashMap<&str, (&str, &str)>> = LazyLock::new(|| {
 	HashMap::from([
 		("size_t", ("size_t", "size_t")),
 		("ptrdiff_t", ("ptrdiff_t", "ptrdiff_t")),
@@ -216,11 +221,11 @@ pub static PRIMITIVE_TYPEDEFS: Lazy<HashMap<&str, (&str, &str)>> = Lazy::new(||
 	])
 });
 
-pub static STATIC_RUST_MODULES: Lazy<BTreeSet<&str>> = Lazy::new(|| BTreeSet::from(["core", "sys", "types"]));
+pub static STATIC_RUST_MODULES: LazyLock<BTreeSet<&str>> = LazyLock::new(|| BTreeSet::from(["core", "sys", "types"]));
 
 /// Types that can be used as `Mat` element
 /// cpp_name(Reference)
-pub static DATA_TYPES: Lazy<HashSet<&str>> = Lazy::new(|| {
+pub static DATA_TYPES: LazyLock<HashSet<&str>> = LazyLock::new(|| {
 	HashSet::from([
 		"unsigned char",
 		"char",
@@ -249,39 +254,40 @@ pub static DATA_TYPES: Lazy<HashSet<&str>> = Lazy::new(|| {
 
 /// Types that can be used as `Mat` element since OpenCV 5.0
 /// cpp_name(Reference)
-pub static DATA_TYPES_5_0: Lazy<HashSet<&str>> =
-	Lazy::new(|| HashSet::from(["uint32_t", "bfloat", "bfloat16_t", "uint64_t", "int64_t", "bool"]));
+pub static DATA_TYPES_5_0: LazyLock<HashSet<&str>> =
+	LazyLock::new(|| HashSet::from(["uint32_t", "bfloat", "bfloat16_t", "uint64_t", "int64_t", "bool"]));
 
-pub static NO_SKIP_NAMESPACE_IN_LOCALNAME: Lazy<HashMap<Option<SupportedModule>, HashMap<&str, &str>>> = Lazy::new(|| {
-	HashMap::from([
-		(None, HashMap::from([("detail", "Detail")])),
-		(Some(SupportedModule::Calib3d), HashMap::from([("fisheye", "Fisheye")])),
-		(Some(SupportedModule::CudaBgSegm), HashMap::from([("cuda", "CUDA")])),
-		(Some(SupportedModule::CudaCodec), HashMap::from([("cudacodec", "CUDA")])),
-		(Some(SupportedModule::CudaFeatures2d), HashMap::from([("cuda", "CUDA")])),
-		(Some(SupportedModule::CudaImgProc), HashMap::from([("cuda", "CUDA")])),
-		(Some(SupportedModule::CudaLegacy), HashMap::from([("cuda", "CUDA")])),
-		(Some(SupportedModule::CudaObjDetect), HashMap::from([("cuda", "CUDA")])),
-		(Some(SupportedModule::CudaOptFlow), HashMap::from([("cuda", "CUDA")])),
-		(Some(SupportedModule::CudaStereo), HashMap::from([("cuda", "CUDA")])),
-		(Some(SupportedModule::Gapi), HashMap::from([("imgproc", "ImgProc")])),
-		(Some(SupportedModule::Mcc), HashMap::from([("mcc", "MCC")])),
-		(Some(SupportedModule::Rapid), HashMap::from([("rapid", "Rapid")])),
-		(
-			Some(SupportedModule::Rgbd),
-			HashMap::from([
-				("dynafu", "Dynafu"),
-				("kinfu", "Kinfu"),
-				("colored_kinfu", "ColoredKinfu"),
-				("linemod", "LineMod"),
-			]),
-		),
-		(Some(SupportedModule::Stitching), HashMap::from([("fisheye", "Fisheye")])),
-		(Some(SupportedModule::SuperRes), HashMap::from([("superres", "SuperRes")])),
-	])
-});
+pub static NO_SKIP_NAMESPACE_IN_LOCALNAME: LazyLock<HashMap<Option<SupportedModule>, HashMap<&str, &str>>> =
+	LazyLock::new(|| {
+		HashMap::from([
+			(None, HashMap::from([("detail", "Detail")])),
+			(Some(SupportedModule::Calib3d), HashMap::from([("fisheye", "Fisheye")])),
+			(Some(SupportedModule::CudaBgSegm), HashMap::from([("cuda", "CUDA")])),
+			(Some(SupportedModule::CudaCodec), HashMap::from([("cudacodec", "CUDA")])),
+			(Some(SupportedModule::CudaFeatures2d), HashMap::from([("cuda", "CUDA")])),
+			(Some(SupportedModule::CudaImgProc), HashMap::from([("cuda", "CUDA")])),
+			(Some(SupportedModule::CudaLegacy), HashMap::from([("cuda", "CUDA")])),
+			(Some(SupportedModule::CudaObjDetect), HashMap::from([("cuda", "CUDA")])),
+			(Some(SupportedModule::CudaOptFlow), HashMap::from([("cuda", "CUDA")])),
+			(Some(SupportedModule::CudaStereo), HashMap::from([("cuda", "CUDA")])),
+			(Some(SupportedModule::Gapi), HashMap::from([("imgproc", "ImgProc")])),
+			(Some(SupportedModule::Mcc), HashMap::from([("mcc", "MCC")])),
+			(Some(SupportedModule::Rapid), HashMap::from([("rapid", "Rapid")])),
+			(
+				Some(SupportedModule::Rgbd),
+				HashMap::from([
+					("dynafu", "Dynafu"),
+					("kinfu", "Kinfu"),
+					("colored_kinfu", "ColoredKinfu"),
+					("linemod", "LineMod"),
+				]),
+			),
+			(Some(SupportedModule::Stitching), HashMap::from([("fisheye", "Fisheye")])),
+			(Some(SupportedModule::SuperRes), HashMap::from([("superres", "SuperRes")])),
+		])
+	});
 
-pub static PREVENT_VECTOR_TYPEDEF_GENERATION: Lazy<HashSet<&str>> = Lazy::new(|| {
+pub static PREVENT_VECTOR_TYPEDEF_GENERATION: LazyLock<HashSet<&str>> = LazyLock::new(|| {
 	HashSet::from([
 		// `MatShape` is an alias to `Vector<i32>` and this leads to duplication of definition for the `Vector<Vector<i32>>` type
 		"cv::dnn::MatShape",
