@@ -6,7 +6,6 @@ use std::rc::Rc;
 use clang::{Entity, EntityKind};
 pub use desc::TypedefDesc;
 
-use crate::comment::strip_doxygen_comment_markers;
 use crate::debug::{DefinitionLocation, LocationName};
 use crate::element::ExcludeKind;
 use crate::type_ref::{CppNameStyle, NameStyle, TypeRefDesc, TypeRefKind, TypeRefTypeHint};
@@ -49,7 +48,7 @@ impl<'tu, 'ge> Typedef<'tu, 'ge> {
 						out = NewTypedefResult::Class(Class::new_ext(child, entity.cpp_name(CppNameStyle::Reference), gen_env));
 					}
 					EntityKind::EnumDecl => {
-						out = NewTypedefResult::Enum(Enum::new_ext(child, entity.cpp_name(CppNameStyle::Reference)));
+						out = NewTypedefResult::Enum(Enum::new_ext(child, entity.cpp_name(CppNameStyle::Reference), gen_env));
 					}
 					_ => {}
 				}
@@ -120,21 +119,21 @@ impl Element for Typedef<'_, '_> {
 		}
 	}
 
-	fn doc_comment(&self) -> Cow<str> {
+	fn doc_comment(&self) -> Cow<'_, str> {
 		match self {
-			Self::Clang { entity, .. } => strip_doxygen_comment_markers(&entity.get_comment().unwrap_or_default()).into(),
+			Self::Clang { entity, .. } => entity.doc_comment(),
 			Self::Desc(_) => "".into(),
 		}
 	}
 
-	fn cpp_namespace(&self) -> Cow<str> {
+	fn cpp_namespace(&self) -> Cow<'_, str> {
 		match self {
 			Self::Clang { entity, .. } => DefaultElement::cpp_namespace(*entity).into(),
 			Self::Desc(desc) => desc.cpp_fullname.namespace().into(),
 		}
 	}
 
-	fn cpp_name(&self, style: CppNameStyle) -> Cow<str> {
+	fn cpp_name(&self, style: CppNameStyle) -> Cow<'_, str> {
 		match self {
 			Self::Clang { entity, .. } => DefaultElement::cpp_name(self, *entity, style),
 			Self::Desc(desc) => desc.cpp_fullname.cpp_name_from_fullname(style).into(),
@@ -145,7 +144,7 @@ impl Element for Typedef<'_, '_> {
 pub enum NewTypedefResult<'tu, 'ge> {
 	Typedef(Typedef<'tu, 'ge>),
 	Class(Class<'tu, 'ge>),
-	Enum(Enum<'tu>),
+	Enum(Enum<'tu, 'ge>),
 }
 
 impl NewTypedefResult<'_, '_> {
