@@ -4,9 +4,9 @@ use std::fmt::Write;
 use std::iter;
 use std::iter::{Chain, Once};
 use std::rc::Rc;
+use std::sync::LazyLock;
 use std::vec::IntoIter;
 
-use once_cell::sync::Lazy;
 use Cow::{Borrowed, Owned};
 
 use super::comment::{render_ref, RenderComment};
@@ -54,7 +54,7 @@ impl RustElement for Func<'_, '_> {
 		}
 	}
 
-	fn rust_name(&self, style: NameStyle) -> Cow<str> {
+	fn rust_name(&self, style: NameStyle) -> Cow<'_, str> {
 		match self {
 			&Self::Clang { entity, .. } => DefaultRustNativeElement::rust_name(self, entity, style).into(),
 			Self::Desc(_) => match style {
@@ -69,7 +69,7 @@ impl RustElement for Func<'_, '_> {
 		}
 	}
 
-	fn rust_leafname(&self, _fish_style: FishStyle) -> Cow<str> {
+	fn rust_leafname(&self, _fish_style: FishStyle) -> Cow<'_, str> {
 		if let Some(rust_custom_leafname) = self.rust_custom_leafname() {
 			return rust_custom_leafname.into();
 		}
@@ -194,17 +194,17 @@ impl RustElement for Func<'_, '_> {
 		Owned(rust_name.into_owned())
 	}
 
-	fn rendered_doc_comment(&self, comment_marker: &str, opencv_version: &str) -> String {
-		let mut comment = RenderComment::new(&self.doc_comment_overloaded(), opencv_version);
+	fn rust_doc_comment(&self, comment_marker: &str, opencv_version: &str) -> String {
+		let mut comment = RenderComment::new(self.doc_comment().into_owned(), opencv_version);
 		let args = self.arguments();
 		let (_, default_args) = split_default_args(&args);
 		let default_args_comment = comment::render_cpp_default_args(default_args);
 		if !default_args_comment.is_empty() {
-			if !comment.comment.is_empty() {
-				comment.comment.push_str("\n\n");
+			if !comment.doc_comment.is_empty() {
+				comment.doc_comment.push_str("\n\n");
 			}
-			comment.comment.push_str("## C++ default parameters\n");
-			comment.comment.push_str(default_args_comment.trim_end());
+			comment.doc_comment.push_str("## C++ default parameters\n");
+			comment.doc_comment.push_str(default_args_comment.trim_end());
 		}
 		comment.render_with_comment_marker(comment_marker).into_owned()
 	}
@@ -216,7 +216,8 @@ impl RustNativeGeneratedElement for Func<'_, '_> {
 	}
 
 	fn gen_rust(&self, opencv_version: &str) -> String {
-		static TPL: Lazy<CompiledInterpolation> = Lazy::new(|| include_str!("tpl/func/rust.tpl.rs").compile_interpolation());
+		static TPL: LazyLock<CompiledInterpolation> =
+			LazyLock::new(|| include_str!("tpl/func/rust.tpl.rs").compile_interpolation());
 
 		let name = self.rust_leafname(FishStyle::No);
 		let kind = self.kind();
@@ -308,7 +309,7 @@ impl RustNativeGeneratedElement for Func<'_, '_> {
 			call_args.push("ocvrs_return.as_mut_ptr()".to_string());
 		}
 
-		let doc_comment = self.rendered_doc_comment("///", opencv_version);
+		let doc_comment = self.rust_doc_comment("///", opencv_version);
 		let visibility = if let Some(cls) = as_instance_method {
 			if cls.kind().is_trait() {
 				""
@@ -361,7 +362,8 @@ impl RustNativeGeneratedElement for Func<'_, '_> {
 	}
 
 	fn gen_rust_externs(&self) -> String {
-		static TPL: Lazy<CompiledInterpolation> = Lazy::new(|| include_str!("tpl/func/rust_extern.tpl.rs").compile_interpolation());
+		static TPL: LazyLock<CompiledInterpolation> =
+			LazyLock::new(|| include_str!("tpl/func/rust_extern.tpl.rs").compile_interpolation());
 
 		if matches!(self.rust_extern_definition(), FuncRustExtern::Absent) {
 			return "".to_string();
@@ -415,7 +417,8 @@ impl RustNativeGeneratedElement for Func<'_, '_> {
 	}
 
 	fn gen_cpp(&self) -> String {
-		static TPL: Lazy<CompiledInterpolation> = Lazy::new(|| include_str!("tpl/func/cpp.tpl.cpp").compile_interpolation());
+		static TPL: LazyLock<CompiledInterpolation> =
+			LazyLock::new(|| include_str!("tpl/func/cpp.tpl.cpp").compile_interpolation());
 
 		if matches!(self.cpp_body(), FuncCppBody::Absent) {
 			return "".to_string();
@@ -526,8 +529,8 @@ fn rust_call(
 	return_kind: ReturnKind,
 ) -> String {
 	#![allow(clippy::too_many_arguments)]
-	static CALL_TPL: Lazy<CompiledInterpolation> =
-		Lazy::new(|| "{{ret_receive}}unsafe { sys::{{identifier}}({{call_args}}) };".compile_interpolation());
+	static CALL_TPL: LazyLock<CompiledInterpolation> =
+		LazyLock::new(|| "{{ret_receive}}unsafe { sys::{{identifier}}({{call_args}}) };".compile_interpolation());
 
 	let ret_receive = if return_kind.is_naked() {
 		"let ret = "
@@ -648,19 +651,21 @@ fn rust_return_map(return_type: &TypeRef, ret_name: &str, return_kind: ReturnKin
 }
 
 fn cpp_call(f: &Func, kind: &FuncKind, call_args: &[String], return_type_ref: &TypeRef) -> String {
-	static CALL_TPL: Lazy<CompiledInterpolation> = Lazy::new(|| "{{name}}({{args}})".compile_interpolation());
+	static CALL_TPL: LazyLock<CompiledInterpolation> = LazyLock::new(|| "{{name}}({{args}})".compile_interpolation());
 
-	static VOID_TPL: Lazy<CompiledInterpolation> = Lazy::new(|| "{{call}};".compile_interpolation());
+	static VOID_TPL: LazyLock<CompiledInterpolation> = LazyLock::new(|| "{{call}};".compile_interpolation());
 
-	static RETURN_TPL: Lazy<CompiledInterpolation> =
-		Lazy::new(|| "{{ret_with_type}} = {{doref}}{{call}};".compile_interpolation());
+	static RETURN_TPL: LazyLock<CompiledInterpolation> =
+		LazyLock::new(|| "{{ret_with_type}} = {{doref}}{{call}};".compile_interpolation());
 
-	static CONSTRUCTOR_TPL: Lazy<CompiledInterpolation> = Lazy::new(|| "{{ret_with_type}}({{args}});".compile_interpolation());
+	static CONSTRUCTOR_TPL: LazyLock<CompiledInterpolation> =
+		LazyLock::new(|| "{{ret_with_type}}({{args}});".compile_interpolation());
 
-	static CONSTRUCTOR_NO_ARGS_TPL: Lazy<CompiledInterpolation> = Lazy::new(|| "{{ret_with_type}};".compile_interpolation());
+	static CONSTRUCTOR_NO_ARGS_TPL: LazyLock<CompiledInterpolation> =
+		LazyLock::new(|| "{{ret_with_type}};".compile_interpolation());
 
-	static BOXED_CONSTRUCTOR_TPL: Lazy<CompiledInterpolation> =
-		Lazy::new(|| "{{ret_type}}* ret = new {{ret_type}}({{args}});".compile_interpolation());
+	static BOXED_CONSTRUCTOR_TPL: LazyLock<CompiledInterpolation> =
+		LazyLock::new(|| "{{ret_type}}* ret = new {{ret_type}}({{args}});".compile_interpolation());
 
 	let call_args = call_args.join(", ");
 
@@ -903,7 +908,7 @@ fn companion_func_default_args<'tu, 'ge>(f: &Func<'tu, 'ge>) -> Option<Func<'tu,
 	}
 	let original_rust_leafname = f.rust_leafname(FishStyle::No);
 	let mut doc_comment = f.doc_comment().into_owned();
-	let rust_leafname = format!("{}_def", original_rust_leafname);
+	let rust_leafname = format!("{original_rust_leafname}_def");
 	let default_args = comment::render_cpp_default_args(args_with_def);
 	if !doc_comment.is_empty() {
 		doc_comment.push_str("\n\n");
