@@ -1,7 +1,6 @@
 use std::borrow::Cow;
 use std::collections::HashMap;
-
-use once_cell::sync::Lazy;
+use std::sync::LazyLock;
 
 use super::element::{DefaultRustNativeElement, RustElement};
 use super::type_ref::TypeRefExt;
@@ -20,11 +19,11 @@ impl RustElement for Tuple<'_, '_> {
 		DefaultRustNativeElement::rust_module(self.entity())
 	}
 
-	fn rust_name(&self, style: NameStyle) -> Cow<str> {
+	fn rust_name(&self, style: NameStyle) -> Cow<'_, str> {
 		DefaultRustNativeElement::rust_name(self, self.entity(), style).into()
 	}
 
-	fn rust_leafname(&self, fish_style: FishStyle) -> Cow<str> {
+	fn rust_leafname(&self, fish_style: FishStyle) -> Cow<'_, str> {
 		format!(
 			"Tuple{fish}<{inner}>",
 			fish = fish_style.rust_qual(),
@@ -32,10 +31,6 @@ impl RustElement for Tuple<'_, '_> {
 		)
 		.into()
 	}
-
-	fn rendered_doc_comment(&self, comment_marker: &str, opencv_version: &str) -> String {
-		DefaultRustNativeElement::rendered_doc_comment(self.entity(), comment_marker, opencv_version)
-	}
 }
 
 impl RustNativeGeneratedElement for Tuple<'_, '_> {
@@ -44,7 +39,8 @@ impl RustNativeGeneratedElement for Tuple<'_, '_> {
 	}
 
 	fn gen_rust(&self, _opencv_version: &str) -> String {
-		static RUST_TPL: Lazy<CompiledInterpolation> = Lazy::new(|| include_str!("tpl/tuple/rust.tpl.rs").compile_interpolation());
+		static RUST_TPL: LazyLock<CompiledInterpolation> =
+			LazyLock::new(|| include_str!("tpl/tuple/rust.tpl.rs").compile_interpolation());
 
 		let type_ref = self.type_ref();
 		let rust_localalias = self.rust_localalias();
@@ -85,7 +81,8 @@ impl RustNativeGeneratedElement for Tuple<'_, '_> {
 	}
 
 	fn gen_cpp(&self) -> String {
-		static CPP_TPL: Lazy<CompiledInterpolation> = Lazy::new(|| include_str!("tpl/tuple/cpp.tpl.cpp").compile_interpolation());
+		static CPP_TPL: LazyLock<CompiledInterpolation> =
+			LazyLock::new(|| include_str!("tpl/tuple/cpp.tpl.cpp").compile_interpolation());
 
 		CPP_TPL.interpolate(&HashMap::from([(
 			"methods",
@@ -109,13 +106,13 @@ fn extern_functions<'tu, 'ge>(tuple: &Tuple<'tu, 'ge>) -> Vec<Func<'tu, 'ge>> {
 }
 
 pub trait TupleExt {
-	fn rust_localalias(&self) -> Cow<str>;
+	fn rust_localalias(&self) -> Cow<'_, str>;
 	fn rust_inner(&self) -> String;
 	fn rust_element_module(&self) -> SupportedModule;
 }
 
 impl TupleExt for Tuple<'_, '_> {
-	fn rust_localalias(&self) -> Cow<str> {
+	fn rust_localalias(&self) -> Cow<'_, str> {
 		const PREFIX: &str = "TupleOf";
 
 		let elems = self.elements();
